<table style="border-collapse: collapse; width: 100%;">
    <thead>
        <tr>
            <th style="border: 1px solid #ddd; padding: 8px; background: #f5f5f5;">Champ</th>
            <th style="border: 1px solid #ddd; padding: 8px; background: #f5f5f5;">Ancienne valeur</th>
            <th style="border: 1px solid #ddd; padding: 8px; background: #f5f5f5;">Nouvelle valeur</th>
        </tr>
    </thead>
        <tbody>
            <tr>
                <td style="border: 1px solid #ddd; padding: 8px;"><strong>{{field}}</strong></td>
                <td style="border: 1px solid #ddd; padding: 8px; background: #fff3cd;">{{old_val}}</td>
                <td style="border: 1px solid #ddd; padding: 8px; background: #d4edda;">{{new_val}}</td>
            </tr>
    </tbody></table>